-----------------------------------------------------------------------------
-- WIN.E - routines for Windows 95-like windows, dialog boxes, buttons etc --
-----------------------------------------------------------------------------
-- By Mike Fowler: mike.fowler@nelsun.gen.nz                               --
-----------------------------------------------------------------------------
-- If you want to use these routines, feel free, but please mail me so I   --
-- can send you updates as they happen :)                                  --
-----------------------------------------------------------------------------
-- For help, read win.doc                                                  --
-----------------------------------------------------------------------------

--------------
-- includes --
--------------
include putsxy.e    -- Credit: David Alan Gay
include graphics.e

--------------
-- varibles --
--------------
global sequence mouse_box, scheme

mouse_box = {}

-- Colour Scheme. Alter to your liking. Currently at windows default colours.
scheme = {15, 0, 7, 7, 1, 7, 0}

---------------
-- constants --
---------------
constant CLOSE = 3, RESTORE = 2, MINIMIZE = 1

-----------------------------------------------------------------------------
--                                  routines                               --
-----------------------------------------------------------------------------
procedure button(atom x, atom y, atom btn_type)
    sequence btn
    atom size
    size = 12   -- Just makes altering button size easier
    btn = {{x, y}, {(x + size), y}, {(x + size), (y + size)}, {x, (y + size)}}
    polygon(scheme[3], 1, btn)
    draw_line(scheme[1], {btn[4], btn[1], btn[2]})
    draw_line(scheme[2], {btn[4], btn[3], btn[2]})
    if btn_type >= 3 then
    -- Drawn with lines not just an 'x' for looks :)
draw_line(scheme[7], {{(x + 3), (y + size) - 3}, {(x + size) - 3, (y + 3)}})
draw_line(scheme[7], {btn[1] + 3, btn[3] - 3})
draw_line(scheme[7], {{(x + 3), (y + size) - 4}, {(x + size) - 4, (y + 3)}})
draw_line(scheme[7], {{(x + 4), (y + 3)}, {(x + size) - 3, (y + size) - 4}})
    elsif btn_type = 2 then
	draw_line(scheme[7], {(btn[1] + 3), {(x + size) - 3, y + 3}})
	draw_line(scheme[7], {(btn[1] + 4), {(x + size) - 3, y + 4}})
	draw_line(scheme[7], {(btn[3] - 3), {(x + size) - 3, y + 3}})
	draw_line(scheme[7], {(btn[1] + 3), {x + 3, (y + size) - 3}})
	draw_line(scheme[7], {(btn[3] - 3), {x + 3, (y + size) - 3}})
    elsif btn_type = 1 then
	draw_line(scheme[7], {(btn[3] - 3), {x + 3, (y + size) - 3}})
    end if
    return
end procedure

-----------------------------------------------------------------------------
--                              global routines                            --
-----------------------------------------------------------------------------
-----------------
-- box routine --
-----------------
global procedure box(atom x1, atom y1, atom x2, atom y2, atom fill)
    if fill < 0 then
	polygon(scheme[3], 1, {{x1, y1}, {x2, y1}, {x2, y2}, {x1, y2}})
    else
	polygon(fill, 1, {{x1, y1}, {x2, y1}, {x2, y2}, {x1, y2}})
    end if
    draw_line(scheme[1], {{x1, y2}, {x1, y1}, {x2, y1}})
    draw_line(scheme[2], {{x1, y2}, {x2, y2}, {x2, y1}})
    return
end procedure

------------------------
-- dialog box routine --
------------------------
global procedure dialog_box(atom x1, atom y1, atom x2, atom y2, sequence heading)
    atom y
    y = y1 + 17
    polygon(scheme[4], 1, {{x1, y1}, {x2, y1}, {x2, y2}, {x1, y2}})
    polygon(scheme[5], 1, {{x1, y1}, {x2, y1}, {x2, y}, {x1, y}})
    draw_line(scheme[1], {{x1, y2}, {x1, y1}, {x2, y1}})
    draw_line(scheme[2], {{x1, y2}, {x2, y2}, {x2, y1}})
    putsxy({(x1 + 10), (y1 + 2)}, heading, scheme[1], scheme[5], 'a')
    button((x2 - 14), (y1 + 3), CLOSE)
end procedure

--------------------
-- window routine --
--------------------
global procedure window(sequence name, atom x1, atom y1, atom x2, atom y2, atom style)
    atom y
    y = y1 + 17
    polygon(scheme[3], 1, {{x1 + 1, y + 1}, {x2 - 1, y + 1}, {x2 - 1, y2 - 1}, {x1 + 1, y2 - 1}})
    polygon(scheme[5], 1, {{x1, y1}, {x2, y1}, {x2, y}, {x1, y}})
    if style = 1 then
	draw_line(scheme[2], {{x1 + 4, y2 - 40}, {x1 + 4, y + 4}, {x2 - 4, y + 4}})
	draw_line(scheme[1], {{x1 + 4, y2 - 40}, {x2 - 4, y2 - 40}, {x2 - 4, y + 4}})
    end if
    draw_line(scheme[1], {{x1, y2}, {x1, y1}, {x2, y1}})
    draw_line(scheme[2], {{x1, y2}, {x2, y2}, {x2, y1}})
    putsxy({(x1 + 10), (y1 + 2)}, name, scheme[1], scheme[5], 'a')
    button((x2 - 14), (y1 + 3), CLOSE)
    button((x2 - 29), (y1 + 3), RESTORE)
    button((x2 - 43), (y1 + 3), MINIMIZE)
end procedure

-------------------------
-- push_button routine --
-------------------------
global procedure push_button(atom x1, atom y1, atom x2, atom y2, sequence text)
    atom x, y, l
    l = length(text) * 4
    polygon(scheme[3], 1, {{x1, y1}, {x2, y1}, {x2, y2}, {x1, y2}})
    draw_line(scheme[1], {{x1, y2}, {x1, y1}, {x2, y1}})
    draw_line(scheme[2], {{x1, y2}, {x2, y2}, {x2, y1}})
    x = ((x2 - x1) / 2) + x1 - l
    y = ((y2 - y1) / 2) + y1 - 8
    putsxy({x, y}, text, scheme[7], scheme[3], 'a')
    mouse_box = append(mouse_box, {x1, y1, x2, y2, text})
end procedure

---------------------
-- taskbar routine --
---------------------
global procedure taskbar(atom height)
    atom y
    y = 479 - (height * 25)
    polygon(scheme[3], 1, {{0, y}, {639, y}, {639, 479}, {0, 479}})
    draw_line(scheme[1], {{0, y}, {639, y}})
    push_button(5, (y + 3), 60, (y + 23), "Start")
end procedure
